package com.loafle.overflow.model.sensor;

import com.loafle.overflow.model.meta.MetaCrawler;
import com.loafle.overflow.model.meta.MetaSensorDisplayItem;
import com.loafle.overflow.model.meta.MetaSensorStatus;
import com.loafle.overflow.model.target.Target;
import org.hibernate.annotations.OnDelete;
import org.hibernate.annotations.OnDeleteAction;

import javax.persistence.*;
import java.util.Date;
import java.util.List;

/**
 * Created by root on 17. 6. 22.
 */
@Entity
@Table(name = "SENSOR", schema = "public")
public class Sensor {
    private Long id;
    private Date createDate;
    private String description;
    private MetaSensorStatus status;
    private Target target;
    private MetaCrawler crawler;
    private String crawlerInputItems;
    private Short itemCount = 0;
    private String displayName;

    // Transient property
    private List<MetaSensorDisplayItem> sensorItems;

    @Id
    @GeneratedValue(strategy= GenerationType.IDENTITY)
    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    @Temporal(TemporalType.TIMESTAMP)
    @Column(name = "CREATE_DATE", nullable = false, columnDefinition = "TIMESTAMP DEFAULT CURRENT_TIMESTAMP", insertable = false, updatable = false)
    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    @Column(name = "DESCRIPTION", nullable = true, length = 50)
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    @ManyToOne
    @JoinColumn(name = "STATUS")
    public MetaSensorStatus getStatus() {
        return status;
    }

    public void setStatus(MetaSensorStatus status) {
        this.status = status;
    }

    @ManyToOne
    @OnDelete(action = OnDeleteAction.CASCADE)
    @JoinColumn(name = "TARGET_ID", nullable = false)
    public Target getTarget() {
        return target;
    }

    public void setTarget(Target target) {
        this.target = target;
    }

    @ManyToOne
    @JoinColumn(name = "CRAWLER_ID", nullable = false)
    public MetaCrawler getCrawler() {
        return crawler;
    }

    public void setCrawler(MetaCrawler crawler) {
        this.crawler = crawler;
    }

    @Column(name = "CRAWLER_INPUT_ITEMS", nullable = true, length = 50)
    public String getCrawlerInputItems() {
        return crawlerInputItems;
    }

    public void setCrawlerInputItems(String crawlerInputItems) {
        this.crawlerInputItems = crawlerInputItems;
    }

    @Column(name = "ITEM_COUNT", nullable = false)
    public Short getItemCount() {
        return itemCount;
    }

    public void setItemCount(Short itemCount) {
        this.itemCount = itemCount;
    }

    @Column(name = "DISPLAY_NAME", nullable = false, length = 50)
	public String getDisplayName() {
		return displayName;
	}

	public void setDisplayName(String displayName) {
		this.displayName = displayName;
    }
    
    @PrePersist
    void preInsert() {
        this.itemCount = 0;
    }

    @Transient
	public List<MetaSensorDisplayItem> getSensorItems() {
		return sensorItems;
	}

	public void setSensorItems(List<MetaSensorDisplayItem> sensorItems) {
		this.sensorItems = sensorItems;
	}


}
